==> nichecompass-0.2.0.tar.gz: nichecompass-0.2.0/docs/index.md <==
# Documentation

NicheCompass (**N**iche **I**dentification based on **C**ellular grap**H** **E**mbeddings of **COM**munication **P**rograms **A**ligned across **S**patial **S**amples) is a package for end-to-end analysis of spatial multi-omics data, including spatial atlas building, niche identification & characterization, cell-cell communication inference and spatial reference mapping. It is built on top of [PyG](https://pytorch-geometric.readthedocs.io/en/latest/) and [AnnData](https://anndata.readthedocs.io/en/latest/).
The package is developed and maintained by the [Lotfollahi Lab](https://github.com/Lotfollahi-lab) at the Wellcome Sanger Institute.

::::{grid} 1 2 3 3
:gutter: 2

:::{grid-item-card} Installation {octicon}`plug;1em;`
:link: installation
:link-type: doc

Check out the installation guide.
:::

:::{grid-item-card} Tutorials {octicon}`play;1em;`
:link: tutorials/index
:link-type: doc

Learn by following example applications of NicheCompass.
:::

:::{grid-item-card} API {octicon}`info;1em;`
:link: api/index
:link-type: doc

Find a detailed description of NicheCompass APIs.
:::

:::{grid-item-card} Release Notes {octicon}`book;1em;`
:link: release_notes/index
:link-type: doc

Follow the latest changes to NicheCompass.
:::

:::{grid-item-card} Contributing {octicon}`code;1em;`
:link: contributing
:link-type: doc

Help improve NicheCompass.
:::
::::

If you find NicheCompass useful for your research, please consider citing the NicheCompass manuscript.

```{toctree}
:hidden: true
:maxdepth: 3
:titlesonly: true

installation
tutorials/index
api/index
release_notes/index
contributing.md
references.md
```

==> nichecompass-0.2.3.tar.gz: nichecompass-0.2.3/docs/index.md <==
# Documentation

NicheCompass (**N**iche **I**dentification based on **C**ellular grap**H** **E**mbeddings of **COM**munication **P**rograms **A**ligned across **S**patial **S**amples) is a package for end-to-end analysis of spatial multi-omics data, including spatial atlas building, niche identification & characterization, cell-cell communication inference and spatial reference mapping. It is built on top of [PyG](https://pytorch-geometric.readthedocs.io/en/latest/) and [AnnData](https://anndata.readthedocs.io/en/latest/).
The package is developed and maintained by the [Lotfollahi Lab](https://github.com/Lotfollahi-lab) at the Wellcome Sanger Institute.

::::{grid} 1 2 3 3
:gutter: 2

:::{grid-item-card} Installation {octicon}`plug;1em;`
:link: installation
:link-type: doc

Check out the installation guide.
:::

:::{grid-item-card} Tutorials {octicon}`play;1em;`
:link: tutorials/index
:link-type: doc

Learn by following example applications of NicheCompass.
:::

:::{grid-item-card} User Guide {octicon}`book;1em;`
:link: user_guide/index
:link-type: doc

Review good practices for training NicheCompass models on your own data.
:::

:::{grid-item-card} API {octicon}`info;1em;`
:link: api/index
:link-type: doc

Find a detailed description of NicheCompass APIs.
:::

:::{grid-item-card} Release Notes {octicon}`tag;1em;`
:link: release_notes/index
:link-type: doc

Follow the latest changes to NicheCompass.
:::

:::{grid-item-card} Contributing {octicon}`code;1em;`
:link: contributing
:link-type: doc

Help improve NicheCompass.
:::
::::

If you find NicheCompass useful for your research, please consider citing the NicheCompass manuscript.

```{toctree}
:hidden: true
:maxdepth: 3
:titlesonly: true

installation
tutorials/index
api/index
release_notes/index
contributing.md
references.md
```
